#==============================================================================
#
# Postcard Direct common routines
#
#==============================================================================

#-----------------------------------------------------------------------------
# Check for bad path names to make sure they can't be abused.
#
# A valid filename is determined to be a valid word character a hyphen and
# a dot.
#
# If type is 'single' - no directories are allowed (default)
#
# If type is 'subdir' - subdirs are OK, but parent dirs are not. 
# ie: ../ or / or C:/ or \\
#
sub CheckBadPath {
	my ($path,$type) = @_;
	my $illegal=0;

	if ($type eq 'subdir') {
		if ($path =~ m#\.\.|^[/\\]|^[a-zA-Z]+:#) {
			$illegal=1;
		}
		elsif ($path !~ m#^([-\w./\\]+)$#) {
			$illegal=1;
		}
	}	
	else {
		$illegal=1 if ($path !~ m#^([-\w.]+)$#);
	}

	return $illegal;
}

#------------------------------------------------------------------------------
# Checks for valid username and password
#
sub CheckPass {
	my ($user,$password)=@_;
	my $authfile="$admin_dir/auth";

	open(AUTH,$authfile) or Error("Can not open authfile: $authfile",$!);
	my $entry=<AUTH>;
	close(AUTH);

	my ($auser,$apassword) = split(/:/,$entry);
	chomp ($auser,$apassword);

	# Decrypt the cookie so it can be run through
	# the crypt function.
	my $key = $ENV{'HTTP_USER_AGENT'};

	$user = decrypt(pack("H*",$user),$key);
	$password = decrypt(pack("H*",$password),$key);
	$apassword = decrypt($apassword,$tkey);

	return 1 if (($password ne $apassword) or ($user ne $auser));
}

#------------------------------------------------------------------------------
# Encrypt username/password using TEA algorithm
sub Encrypt {
	my ($user,$password) = @_;

	my $key = $ENV{'HTTP_USER_AGENT'};

	$user = encrypt($user,$key);
	$password = encrypt($password,$key);

	# Turn it into a usable format for cookies
	$user = unpack("H*",$user);
	$password = unpack("H*",$password);

	return $user,$password;
}

#------------------------------------------------------------------------------
# Return a CSS
#
sub Stylesheet {
	my $stylesheet = shift;

	open STYLE,"$style_dir/$stylesheet"  or Error("Can not open $style_dir/$stylesheet",$!);
	my @style=<STYLE>;
	close(STYLE);

	return "@style";
}

#------------------------------------------------------------------------------
sub CheckReferer {
	Error("HTTP_REFERER not set",undef,1) unless $ENV{HTTP_REFERER};

	my ($host,$thishost);

	($host) = $ENV{HTTP_REFERER} =~ m!https*://([\w\.-]+)/!;
	$thishost = $ENV{HTTP_HOST};

	if ($host ne $thishost) {
		if ($admin_referers) {
			my $valid=0;
			foreach my $referer (split(/,/,$admin_referers)) {
				if ($host eq $referer) {
					$valid=1;
					last;
				}
			}
			Error("Invalid HTTP_REFERER",$ENV{HTTP_REFERER},1) unless $valid;

		}
		else {
			Error("Invalid HTTP_REFERER $host",$ENV{HTTP_REFERER},1);
		}
	}

}

#------------------------------------------------------------------------------
# Display Error message
#
sub Error {
	my ($error,$details,$header)=@_;


	print "Content-Type: text/html\n\n" if $header;
	$details='None' unless $details;
	my $time=localtime();

	print <<HTML;
<html>
<head>
<title>$error</title>
</head>

<body bgcolor="#ffffff">

<blockquote>
<p>
<font face="Arial,Helvetica">
<table border="0" cellpadding="5" bgcolor="yellow">
<tr>
<td>$error</td>
</tr>
</table>
</font>
</p>

<hr>
<font face="Arial,Helvetica">
<h3>Diagnostics</h3>
Error Message: <i>$details</i><br>
Script Version: <i>$version</i><br>
Perl Version: <i>$]</i><br>
Server Type: <i>$ENV{'SERVER_SOFTWARE'}</i><br>
Server Time: <i>$time</i><br>

<script language="javascript">
<!--
document.write("Your Time: <i>" +  Date() + "</i><br>")
-->
</script>

</font>

<hr>

<p>This error might be covered in the <a href="http://postcard-direct.com/faq.html">Postcard Direct FAQ.</a></p>

</blockquote>

</body>
</html>
HTML

	exit;
}

#-----------------------------------------------------------------------------
sub Checklogin {
	my $q = shift;

	my $user = $q->cookie('user');
	my $password = $q->cookie('password');

	if (CheckPass($user,$password)) {
		print "<h2>Not Authorised or session has timed out</h2>\n";
		print qq[<input type=button value="Close" onClick="window.close()">\n];
		exit;
	}
}

#-----------------------------------------------------------------------------

1;
